Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Elastic Load Balancing V2.

Actions, resources, and condition keys for AWS Elastic Load Balancing V2 - Service Authorization Reference

# Actions, resources, and condition keys for AWS Elastic Load Balancing V2

AWS Elastic Load Balancing V2 (service prefix: `elasticloadbalancing` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Elastic Load Balancing V2
- Resource types defined by AWS Elastic Load Balancing V2
- Condition keys for AWS Elastic Load Balancing V2

## Actions defined by AWS Elastic Load Balancing V2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddListenerCertificates | Grants permission to add the specified certificates to the specified secure listener | Write | listener/app* |  |
listener/net* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
AddTags | Grants permission to add the specified tags to the specified load balancer. Each load balancer can have a maximum of 10 tags | Tagging | listener-rule/app |  |
listener-rule/net |  |
listener/app |  |
listener/net |  |
loadbalancer/app/ |  |
loadbalancer/net/ |  |
targetgroup |  |
| aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} elasticloadbalancing:CreateAction |
CreateListener | Grants permission to create a listener for the specified Application Load Balancer | Write | loadbalancer/app/ |  | elasticloadbalancing:AddTags
loadbalancer/net/ |  |
| aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
CreateLoadBalancer | Grants permission to create a load balancer | Write | loadbalancer/app/ |  | elasticloadbalancing:AddTags
loadbalancer/net/ |  |
| aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
CreateRule | Grants permission to create a rule for the specified listener | Write | listener/app* |  | elasticloadbalancing:AddTags
listener/net* |  |
| aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
CreateTargetGroup | Grants permission to create a target group | Write | targetgroup* |  | elasticloadbalancing:AddTags
| aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
DeleteListener | Grants permission to delete the specified listener | Write | listener/app* |  |
listener/net* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
DeleteLoadBalancer | Grants permission to delete the specified load balancer | Write | loadbalancer/app/ |  |
loadbalancer/net/ |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
DeleteRule | Grants permission to delete the specified rule | Write | listener-rule/app* |  |
listener-rule/net* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
DeleteTargetGroup | Grants permission to delete the specified target group | Write | targetgroup* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
DeregisterTargets | Grants permission to deregister the specified targets from the specified target group | Write | targetgroup* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
DescribeAccountLimits | Grants permission to describe the Elastic Load Balancing resource limits for the AWS account | Read |  |  |
DescribeListenerCertificates | Grants permission to describe the certificates for the specified secure listener | Read |  |  |
DescribeListeners | Grants permission to describe the specified listeners or the listeners for the specified Application Load Balancer | Read |  |  |
DescribeLoadBalancerAttributes | Grants permission to describe the attributes for the specified load balancer | Read |  |  |
DescribeLoadBalancers | Grants permission to describe the specified the load balancers. If no load balancers are specified, the call describes all of your load balancers | Read |  |  |
DescribeRules | Grants permission to describe the specified rules or the rules for the specified listener | Read |  |  |
DescribeSSLPolicies | Grants permission to describe the specified policies or all policies used for SSL negotiation | Read |  |  |
DescribeTags | Grants permission to describe the tags associated with the specified resource | Read |  |  |
DescribeTargetGroupAttributes | Grants permission to describe the attributes for the specified target group | Read |  |  |
DescribeTargetGroups | Grants permission to describe the specified target groups or all of your target groups | Read |  |  |
DescribeTargetHealth | Grants permission to describe the health of the specified targets or all of your targets | Read |  |  |
ModifyListener | Grants permission to modify the specified properties of the specified listener | Write | listener/app* |  |
listener/net* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
ModifyLoadBalancerAttributes | Grants permission to modify the attributes of the specified load balancer | Write | loadbalancer/app/ |  |
loadbalancer/net/ |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
ModifyRule | Grants permission to modify the specified rule | Write | listener-rule/app* |  |
listener-rule/net* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
ModifyTargetGroup | Grants permission to modify the health checks used when evaluating the health state of the targets in the specified target group | Write | targetgroup* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
ModifyTargetGroupAttributes | Grants permission to modify the specified attributes of the specified target group | Write | targetgroup* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
RegisterTargets | Grants permission to register the specified targets with the specified target group | Write | targetgroup* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
RemoveListenerCertificates | Grants permission to remove the specified certificates of the specified secure listener | Write | listener/app* |  |
listener/net* |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
RemoveTags | Grants permission to remove one or more tags from the specified load balancer | Tagging | listener-rule/app |  |
listener-rule/net |  |
listener/app |  |
listener/net |  |
loadbalancer/app/ |  |
loadbalancer/net/ |  |
targetgroup |  |
| aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
SetIpAddressType | Grants permission to set the type of IP addresses used by the subnets of the specified load balancer | Write | loadbalancer/app/ |  |
loadbalancer/net/ |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
SetRulePriorities | Grants permission to set the priorities of the specified rules | Write | listener-rule/app* |  |
listener-rule/net* |  |
SetSecurityGroups | Grants permission to associate the specified security groups with the specified load balancer | Write | loadbalancer/app/ |  |
loadbalancer/net/ |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
SetSubnets | Grants permission to enable the Availability Zone for the specified subnets for the specified load balancer | Write | loadbalancer/app/ |  |
loadbalancer/net/ |  |
| aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey} |
SetWebAcl [permission only] | Grants permission to give WebAcl permission to WAF | Write |  |  |

## Resource types defined by AWS Elastic Load Balancing V2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
listener/app | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:listener/app/$ { LoadBalancerName}/$ { LoadBalancerId}/$ { ListenerId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}
listener-rule/app | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:listener-rule/app/$ { LoadBalancerName}/$ { LoadBalancerId}/$ { ListenerId}/$ { ListenerRuleId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}
listener/net | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:listener/net/$ { LoadBalancerName}/$ { LoadBalancerId}/$ { ListenerId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}
listener-rule/net | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:listener-rule/net/$ { LoadBalancerName}/$ { LoadBalancerId}/$ { ListenerId}/$ { ListenerRuleId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}
loadbalancer/app/ | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:loadbalancer/app/$ { LoadBalancerName}/$ { LoadBalancerId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}
loadbalancer/net/ | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:loadbalancer/net/$ { LoadBalancerName}/$ { LoadBalancerId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}
targetgroup | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:targetgroup/$ { TargetGroupName}/$ { TargetGroupId}` | aws:ResourceTag/${TagKey} elasticloadbalancing:ResourceTag/${TagKey}

## Condition keys for AWS Elastic Load Balancing V2

AWS Elastic Load Balancing V2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | ArrayOfString
elasticloadbalancing:CreateAction | Filters access by the name of a resource-creating API action | String
elasticloadbalancing:ResourceTag/${TagKey} | Filters access by the preface string for a tag key and value pair that are attached to a resource | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.